# AutoApiTestRunner
Automation Command Line Tool

## Installation
### Method-1: Using https://pypi.org/project/Test15071993/0.0.0/

Installation Command:
* sudo -H pip install Test15071993

### Method-2: Using pip

Installation Command:
NOTE: you must have a working git over ssh configuration.

* ssh -T git@github.com
    * “Hi kshamashuttl! You've successfully authenticated, but GitHub does not provide shell access.”
* sudo -H python -m pip install --no-cache-dir "git+ssh://git@github.com/Shuttl-Tech/AutoApiTestRunner.git"

Validate the installation by running
- auto --help
